==> kmldonkey-0.9.1.tar.gz: kmldonkey-0.9.1/kmldonkey/webservices.h <==
/* -*- c++ -*-
 *
 * $Id: webservices.h,v 1.2 2003/07/01 22:37:55 gibreel Exp $
 *
 * Copyright (C) 2003 Petter E. Stokke <gibreel@gibreel.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Log: webservices.h,v $
 * Revision 1.2  2003/07/01 22:37:55  gibreel
 * Web services only start loading when or if they're first shown, which is
 * more economical on the network traffic.
 *
 * Revision 1.1  2003/06/30 00:34:03  gibreel
 * Added an embedded web browser class, and through it added Jigle and Bitzi
 * lookups to the file info dialog.
 *
 */

#ifndef __kmldonkey_webservices_h__
#define __kmldonkey_webservices_h__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "webbrowser.h"

class FileInfoWebBrowser : public WebBrowser
{
    Q_OBJECT

public:

    FileInfoWebBrowser(int fileno, QWidget* parent = 0, const char* name = 0);
    virtual void handleED2K(const ED2KURL& url);

public slots:

    virtual void loadWebPage() = 0;

protected:

    void showEvent(QShowEvent* event);

    int fn;
    bool loaded;

};

class BitziFileInfo : public FileInfoWebBrowser
{
    Q_OBJECT

public:

    BitziFileInfo(int fileno, QWidget* parent = 0);

public slots:

    void loadWebPage();

};

class JigleFileInfo : public FileInfoWebBrowser
{
    Q_OBJECT

public:

    JigleFileInfo(int fileno, QWidget* parent = 0);

public slots:

    void loadWebPage();

};


#endif // __kmldonkey_webservices_h__

==> kmldonkey_0.10.orig.tar.gz: kmldonkey-0.10/kmldonkey/webservices.h <==
/* -*- c++ -*-
 *
 * webservices.h
 *
 * Copyright (C) 2003 Petter E. Stokke <gibreel@kmldonkey.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#ifndef __kmldonkey_webservices_h__
#define __kmldonkey_webservices_h__

#include "webbrowser.h"

class FileInfoWebBrowser : public WebBrowser
{
    Q_OBJECT

public:

    FileInfoWebBrowser(int fileno, QWidget* parent = 0, const char* name = 0);
    virtual void handleED2K(const ED2KURL& url);

public slots:

    virtual void loadWebPage() = 0;

protected:

    void showEvent(QShowEvent* event);

    int fn;
    bool loaded;

};

class BitziFileInfo : public FileInfoWebBrowser
{
    Q_OBJECT

public:

    BitziFileInfo(int fileno, QWidget* parent = 0);

public slots:

    void loadWebPage();

};

class FileHashFileInfo : public FileInfoWebBrowser
{
    Q_OBJECT

public:

    FileHashFileInfo(int fileno, QWidget* parent = 0);

public slots:

    void loadWebPage();

};

#endif // __kmldonkey_webservices_h__
